@@ -1,9 +1,21 @@
 from django.core.exceptions import ValidationError
 from django.db import models
 
+from jsonfield.fields import JSONField
+
 from formidable import constants
 from formidable.register import FieldSerializerRegister
-from jsonfield.fields import JSONField
+
+
+def get_serializer(definition_schema, context=None):
+    """
+    Return a FormidableSerializer instance, including eventual context.
+    """
+    from formidable.serializers import FormidableSerializer
+    serializer = FormidableSerializer(data=definition_schema)
+    # pass context to serializer so we can use it during data validation
+    serializer.context.update(context or {})  # If None, will default to {}
+    return serializer
 
 
 class Formidable(models.Model):
@@ -47,9 +59,8 @@ class Formidable(models.Model):
         <Formidable: Formidable object>
 
         """
-        from formidable.serializers import FormidableSerializer
-
-        serializer = FormidableSerializer(data=definition_schema)
+        context = kwargs.pop("context", {})
+        serializer = get_serializer(definition_schema, context)
         if not serializer.is_valid():
             raise ValidationError(serializer.errors)
 
